@@ -28,13 +28,18 @@ class ArgumentParsingTest(TestCase):
 
     def setUp(self):
         super(ArgumentParsingTest, self).setUp()
-        self.devnull = StringIO()
-        self.forge.replace_with(sys, "stderr", self.devnull)
+        self.stderr = StringIO()
+        self.stdout = StringIO()
+        self.addCleanup(setattr, sys, "stderr", sys.stderr)
+        self.forge.replace_with(sys, "stderr", self.stderr)
+        self.addCleanup(setattr, sys, "stdout", sys.stdout)
+        self.forge.replace_with(sys, "stdout", self.stdout)
+
 
     callback_success = False
     def _test_iterator_stub(self, app, args):
         self.assertTrue(config.root.debug.enabled)
-        self.assertEquals(app.args.remainder, ["test1.py", "test2.py"])
+        self.assertEquals(app.args.positionals, ["test1.py", "test2.py"])
         # this must be last to make sure the stub ran successfully
         self.callback_success = True
         return ()
@@ -53,6 +58,32 @@ class ArgumentParsingTest(TestCase):
             code = caught.exception.code
         self.assertEquals(code, 0)
 
+class SlashHelpTest(ArgumentParsingTest):
+
+    def _fake_execute(self, argv):
+        prev_argv = list(sys.argv)
+        sys.argv = argv[:]
+        try:
+            main_entry_point()
+        finally:
+            sys.argv = prev_argv
+
+    def test_slash_run_help(self):
+
+        with self.assertRaises(SystemExit):
+            self._fake_execute(["slash", "run", "-h"])
+
+        self.assertTrue(self.stdout.getvalue().startswith("usage: slash run "))
+        self.assertIn("TEST [TEST ", self.stdout.getvalue())
+
+    def test_slash_help(self):
+
+        with self.assertRaises(SystemExit):
+            self._fake_execute(["slash", "-h"])
+
+        self.assertTrue(self.stdout.getvalue().startswith("usage: slash command..."), self.stdout.getvalue())
+
+
 class SlashRunTest(SlashRunTestBase):
 
     def setUp(self):
@@ -100,7 +131,7 @@ class SlashRunTest(SlashRunTestBase):
 
 
         result = self._execute_slash_run(["-f", filename1, "-f", filename2])
-        self.assertEquals(result, 0, "slash run failed")
+        self.assertEquals(result, 0, "usage: slash run failed")
 
         tests_run = self.generator.get_test_ids_run()
         self.assertEquals(len(tests_run), 3)
